@@ -1,4 +1,4 @@
-from sklearn.linear_model import LogisticRegressionCV
+from sklearn.linear_model import LogisticRegression, LogisticRegressionCV
 
 def create_lr_instance(C = 1.0, penalty = 'l2', multi_class = 'auto'):
 
