@@ -15,7 +15,10 @@ from keras.utils import to_categorical
 import numpy as np
 from tqdm import tqdm
 import time
+import matplotlib.ticker as mticker
 
+import warnings
+warnings.filterwarnings("ignore")
 
 #region Performance Test. Compare NNRW with mainstream classifier models.
 
